@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
-__version__ = '0.1.0'
+__version__ = '0.1.1'
 
-from unsplashx import status, changelog, id, source
+from .unsplashx import status, changelog, id, source
 
 __all__ = ('status', 'changelog', 'id', 'source')
